@@ -262,11 +262,11 @@ class SimpleTensorboardCallback(ActionCallback):
             )
 
 
-class SetCriterion(ActionCallback):
+class SetLossFn(ActionCallback):
     r"""A callback that sets the ``criterion`` (a.k.a. loss function) of the solver.
     Best used together with a condition callback.
 
-    :param criterion:
+    :param loss_fn:
         The loss function to be set for the solver. It can be
 
         - An instance of ``torch.nn.modules.loss._Loss``
@@ -274,7 +274,7 @@ class SetCriterion(ActionCallback):
         - A callable object which maps residuals, function values, and input coordinates to a scalar loss; or
         - A str which is present in ``neurodiffeq.losses._losses.keys()``.
 
-    :type criterion: ``torch.nn.modules.loss._Loss`` or callable or str.
+    :type loss_fn: ``torch.nn.modules.loss._Loss`` or callable or str.
     :param reset:
         If True, the criterion will be reset every time the callback is called.
         Otherwise, the criterion will only be set once.
@@ -284,9 +284,10 @@ class SetCriterion(ActionCallback):
     :type logger: str or ``logging.Logger``
     """
 
-    def __init__(self, criterion, reset=False, logger=None):
-        super(SetCriterion, self).__init__(logger=logger)
-        self.criterion = criterion
+    @deprecated_alias(criterion='loss_fn')
+    def __init__(self, loss_fn, reset=False, logger=None):
+        super(SetLossFn, self).__init__(logger=logger)
+        self.loss_fn = loss_fn
         self.reset = reset
         self.called = False
 
@@ -294,9 +295,11 @@ class SetCriterion(ActionCallback):
         if self.reset or (not self.called):
             self.called = True
             # noinspection PyProtectedMember
-            solver._set_criterion(self.criterion)
+            solver._set_loss_fn(self.loss_fn)
 
 
+SetCriterion = warn_deprecate_class(SetLossFn)
+
 class SetOptimizer(ActionCallback):
     r"""A callback that sets the optimizer of the solver. Best used together with a condition callback.
 
